==> react-native-animmated-image-resizer-1.0.4-beta.1.tgz: package/android/src/main/java/com/imageresizer/MyGifEncoder.java <==
package com.imageresizer;

import android.graphics.Bitmap;

import com.gifencoder.AnimatedGifEncoder;
import com.waynejo.androidndkgif.GifEncoder;

import java.io.File;
import java.io.FileNotFoundException;

public class MyGifEncoder implements MyEncoder{
    private GifEncoder gifEncoder;

    private int quality = 100;
    public MyGifEncoder(File outputFile, int quality) {
        this.gifEncoder = new GifEncoder();
//        this.gifEncoder.init(w, h, outputFile.getAbsolutePath());

        this.quality = quality;

        // extra config

    }

    @Override
    public void setDelay(int delay) {

    }

    @Override
    public void addFrame(Bitmap frame) {
        this.gifEncoder.encodeFrame(frame, 80);
    }

    @Override
    public void close() {
        this.gifEncoder.close();
    }
}
//public class MyGifEncoder implements MyEncoder{
//    private AnimatedGifEncoder gifEncoder;
//
//    private int quality = 100;
//    public MyGifEncoder(File outputFile, int quality) {
//        this.gifEncoder = new AnimatedGifEncoder();
//        this.gifEncoder.start(outputFile.getAbsolutePath());
//
//        this.quality = quality;
//
//        // extra config
//        this.gifEncoder.setRepeat(0);
//        this.gifEncoder.setDelay(80);
//
//    }
//
//    @Override
//    public void setDelay(int delay) {
//        this.gifEncoder.setDelay(delay);
//    }
//
//    @Override
//    public void addFrame(Bitmap frame) {
//        this.gifEncoder.addFrame(frame);
//    }
//
//    @Override
//    public void close() {
//        this.gifEncoder.finish();
//    }
//}

==> react-native-animmated-image-resizer-1.0.6-beta.1.tgz: package/android/src/main/java/com/imageresizer/MyGifEncoder.java <==
package com.imageresizer;

import android.graphics.Bitmap;

import com.gifencoder.AnimatedGifEncoder;
import com.waynejo.androidndkgif.GifEncoder;

import java.io.File;
import java.io.FileNotFoundException;

public class MyGifEncoder implements MyEncoder{
    private GifEncoder gifEncoder;

    private int quality = 100;
    public MyGifEncoder(File outputFile, StaticOptions options) {
        this.gifEncoder= new GifEncoder();
        try {
            this.gifEncoder.init(options.width, options.height, outputFile.getPath());
        } catch (FileNotFoundException e) {
            throw new RuntimeException(e);
        }



    }

    @Override
    public void addFrame(Bitmap frame) {
        // FRAME, Delay
        this.gifEncoder.encodeFrame(frame, 80);
    }

    @Override
    public void close() {
        this.gifEncoder.close();
    }
}
//public class MyGifEncoder implements MyEncoder{
//    private AnimatedGifEncoder gifEncoder;
//
//    private int quality = 100;
//    public MyGifEncoder(File outputFile, int quality) {
//        this.gifEncoder = new AnimatedGifEncoder();
//        this.gifEncoder.start(outputFile.getAbsolutePath());
//
//        this.quality = quality;
//
//        // extra config
//        this.gifEncoder.setRepeat(0);
//        this.gifEncoder.setDelay(80);
//
//    }
//
//    @Override
//    public void setDelay(int delay) {
//        this.gifEncoder.setDelay(delay);
//    }
//
//    @Override
//    public void addFrame(Bitmap frame) {
//        this.gifEncoder.addFrame(frame);
//    }
//
//    @Override
//    public void close() {
//        this.gifEncoder.finish();
//    }
//}
